precision highp float;

__USER_DEFINES__

#define TEX2D(tex, pos) texture2D(tex, pos)

//======================================================================
//Skeleton for ventusky methods with 2 parametr
//======================================================================

varying vec2 vTexCoord; //pro projekce


uniform vec4 minMaxStepOpacity;

uniform sampler2D en_texModel;

//#ifdef SMOOTH_TRANSITION
uniform sampler2D en_texModelPrev;
uniform float smoothStep;
//#endif

uniform sampler2D colorMap;

uniform vec4 texCoordAtlas;

float ConvertPackedValue(__CONVERT_PACKED_VALUE_PARAM__) __CONVERT_PACKED_VALUE_FUNCTION__



vec4 GetUnpackedColor(float val)
{			
	float tx = (val - minMaxStepOpacity.x) / (minMaxStepOpacity.y - minMaxStepOpacity.x);
		
	return texture2D(colorMap, vec2(tx, 0.5));
}

void main()
{	
	vec2 texCoord = vTexCoord + texCoordAtlas.xy;
		
#ifdef GLES_2
	vec2 packedValueRG = TEX2D(en_texModel, texCoord).ra;
#else
	vec2 packedValueRG = TEX2D(en_texModel, texCoord).rg;
#endif

	float unpackedValue = ConvertPackedValue(packedValueRG.x * 255.0, packedValueRG.y * 255.0);

	if (smoothStep < 1.0)
	{

#ifdef GLES_2
		vec2 unpackedValueRGPrev = TEX2D(en_texModelPrev, texCoord).ra;
#else
		vec2 unpackedValueRGPrev = TEX2D(en_texModelPrev, texCoord).rg;
#endif

		float unpackedValuePrev = ConvertPackedValue(unpackedValueRGPrev.x * 255.0, unpackedValueRGPrev.y * 255.0);		
		unpackedValue = mix(unpackedValuePrev, unpackedValue, smoothStep);
	}
			
	vec4 color = GetUnpackedColor(unpackedValue);


	gl_FragColor = color;	
	gl_FragColor.a *= minMaxStepOpacity.w;		 //*= multiply opacity from "color map" with "user defined"
			
	//DEBUG
	//if ((vTexCoord.x < 0.01) || (vTexCoord.x > 0.99)) gl_FragColor.rgb = vec3(1);
	//if ((vTexCoord.y < 0.01) || (vTexCoord.y > 0.99)) gl_FragColor.rgb = vec3(1);	
}
